@@ -1,9 +1,10 @@
 regr<-function (lm.out) 
 {
-    ifelse(length(lm.out$call) > 2, new.data <- eval(as.name(lm.out$call[[3]]), 
-        parent.frame()), new.data <- model.frame(lm.out$call[[2]]))
+#    ifelse(length(lm.out$call) > 2, new.data <- eval(as.name(lm.out$call[[3]]), 
+#        parent.frame()), new.data <- model.frame(lm.out$call[[2]]))
+    new.data<-model.frame(lm.out)
     new.scale <- model.matrix(lm.out)
-    v <- as.numeric(row.names(new.scale))
+#    v <- as.numeric(row.names(new.scale))
 #   new.data <- new.data[v, ]
     IV <- attr(lm.out$terms, "term.labels")
     DV <- dimnames(attr(lm.out$terms, "factors"))[[1]][1]
